OC.L10N.register(
    "photos",
    {
    "Public link" : "Publiskā saite",
    "Photos" : "Fotoattēli",
    "Videos" : "Video",
    "Albums" : "Albumi",
    "People" : "Cilvēki",
    "Folders" : "Mapes",
    "Favorites" : "Izlases vienumi",
    "On this day" : "Šajā dienā",
    "Shared with you" : "Koplietots ar tevi",
    "Tags" : "Birkas",
    "Places" : "Vietas",
    "Map" : "Karte",
    "Name of the album" : "Albuma nosaukums",
    "Location of the album" : "Albuma atrašanās vieta",
    "Back" : "Atpakaļ",
    "Save" : "Saglabāt",
    "Create album" : "Izveidot albumu",
    "Shared by" : "Koplietoja",
    "New album" : "Jauns albums",
    "Group" : "Grupa",
    "Copy the public link" : "Kopējiet publisko saiti",
    "Public link copied!" : "Publiskā saite nokopēta!",
    "Copy public link" : "Kopējiet publisko saiti",
    "Delete the public link" : "Dzēst publisko saiti",
    "Share via public link" : "Kopīgojiet, izmantojot publisko saiti",
    "An error occurred" : "Gadījās kļūda",
    "Favorite" : "Izlasē",
    "Go back" : "Atpakaļ",
    "Dates" : "Datumi",
    "Add folder" : "Pievienot mapi",
    "Home" : "Sākums",
    "View" : "Skats",
    "Edit album details" : "Labot albuma datus",
    "Rename person" : "Pārsaukt personu",
    "Remove from favorites" : "Noņemt no izlases",
    "Remove person" : "Noņemt personu",
    "Back to tags overview" : "Atpakaļ uz birku pārskatu",
    "Add" : "Pievienot",
    "Details" : "Detaļas",
    "Invalid location selected" : "Ir izvēlēta nederīga atrašanās vieta "
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
